summaryrefslogtreecommitdiffstats
path: root/src/usr/diag/prdf/common/framework/config
diff options
context:
space:
mode:
Diffstat (limited to 'src/usr/diag/prdf/common/framework/config')
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/iipConfigurator.C29
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/iipConfigurator.h7
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/iipDomain.C9
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/iipDomain.h4
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/iipDomainContainer.C6
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/iipDomainContainer.h5
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/iipDomainContainer.inl4
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/iipSystem.C16
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/iipSystem.h4
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/iipchip.C9
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/iipchip.h7
-rw-r--r--src/usr/diag/prdf/common/framework/config/prdfExDomain.H11
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/prdfExtensibleChip.H19
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/prdfExtensibleDomain.C26
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/prdfExtensibleDomain.H17
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/prdfFabricDomain.C52
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/prdfFabricDomain.H14
-rw-r--r--src/usr/diag/prdf/common/framework/config/prdfMbaDomain.H11
-rw-r--r--src/usr/diag/prdf/common/framework/config/prdfMcsDomain.H11
-rw-r--r--src/usr/diag/prdf/common/framework/config/prdfMembufDomain.H11
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/prdfParentDomain.C5
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/prdfParentDomain.H4
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/prdfPllDomain.C72
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/prdfPllDomain.H16
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/prdfRuleChipDomain.C27
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/prdfRuleChipDomain.H13
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/prdfSystemSpecific.H7
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/xspprdAccessPllChip.C15
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/config/xspprdAccessPllChip.h5
29 files changed, 253 insertions, 183 deletions
diff --git a/src/usr/diag/prdf/common/framework/config/iipConfigurator.C b/src/usr/diag/prdf/common/framework/config/iipConfigurator.C
index 2b3bb8ca1..a3425a73e 100755
--- a/src/usr/diag/prdf/common/framework/config/iipConfigurator.C
+++ b/src/usr/diag/prdf/common/framework/config/iipConfigurator.C
@@ -34,35 +34,10 @@
#include <iipConfigurator.h>
#undef iipConfigurator_C
-//----------------------------------------------------------------------
-// User Types
-//----------------------------------------------------------------------
-
-//----------------------------------------------------------------------
-// Constants
-//----------------------------------------------------------------------
-
-//----------------------------------------------------------------------
-// Macros
-//----------------------------------------------------------------------
-
-//----------------------------------------------------------------------
-// Internal Function Prototypes
-//----------------------------------------------------------------------
-
-//----------------------------------------------------------------------
-// Global Variables
-//----------------------------------------------------------------------
-
-//---------------------------------------------------------------------
-// Member Function Specifications
-//---------------------------------------------------------------------
namespace PRDF
{
-Configurator::~Configurator()
-{
-}
+Configurator::~Configurator() {}
-} // End namespace PRDF
+} // end namespace PRDF
diff --git a/src/usr/diag/prdf/common/framework/config/iipConfigurator.h b/src/usr/diag/prdf/common/framework/config/iipConfigurator.h
index 311a1fc78..262a9b9e7 100755
--- a/src/usr/diag/prdf/common/framework/config/iipConfigurator.h
+++ b/src/usr/diag/prdf/common/framework/config/iipConfigurator.h
@@ -76,6 +76,10 @@
#include <prdfMain.H>
#include <vector>
+
+namespace PRDF
+{
+
/*--------------------------------------------------------------------*/
/* Forward References */
/*--------------------------------------------------------------------*/
@@ -83,9 +87,6 @@ class CHIP_CLASS;
class Domain;
class System;
-namespace PRDF
-{
-
class Configurator
{
public:
diff --git a/src/usr/diag/prdf/common/framework/config/iipDomain.C b/src/usr/diag/prdf/common/framework/config/iipDomain.C
index 5a86822af..fde702412 100755
--- a/src/usr/diag/prdf/common/framework/config/iipDomain.C
+++ b/src/usr/diag/prdf/common/framework/config/iipDomain.C
@@ -61,6 +61,9 @@
// Member Function Specifications
//---------------------------------------------------------------------
+namespace PRDF
+{
+
Domain::Domain(DOMAIN_ID domain_id) :
dom_id(domain_id)
{
@@ -76,9 +79,9 @@ int32_t Domain::Initialize (void)
return(SUCCESS);
}
-
-// @jl02 Add this for Unit CS. This is a virtual function so it doesn't need and code here.
void Domain::Remove(TARGETING::TargetHandle_t i_ptargetChip)
{
};
-// @jl02 a End.
+
+} // end namespace PRDF
+
diff --git a/src/usr/diag/prdf/common/framework/config/iipDomain.h b/src/usr/diag/prdf/common/framework/config/iipDomain.h
index 4fdab1a57..8545801aa 100755
--- a/src/usr/diag/prdf/common/framework/config/iipDomain.h
+++ b/src/usr/diag/prdf/common/framework/config/iipDomain.h
@@ -31,6 +31,9 @@
#include <iipsdbug.h> // Include file for ATTENTION_TYPE
#endif
+namespace PRDF
+{
+
// Forward References
struct STEP_CODE_DATA_STRUCT;
@@ -122,5 +125,6 @@ private:
};
+} // end namespace PRDF
#endif
diff --git a/src/usr/diag/prdf/common/framework/config/iipDomainContainer.C b/src/usr/diag/prdf/common/framework/config/iipDomainContainer.C
index 2274adce9..09399eb1c 100755
--- a/src/usr/diag/prdf/common/framework/config/iipDomainContainer.C
+++ b/src/usr/diag/prdf/common/framework/config/iipDomainContainer.C
@@ -41,6 +41,9 @@
#include <prdfPlatServices.H>
#include <algorithm>
+namespace PRDF
+{
+
//----------------------------------------------------------------------
// User Types
//----------------------------------------------------------------------
@@ -163,3 +166,6 @@ void DomainContainer<T>::Remove(TARGETING::TargetHandle_t i_pChipHandle)
// This will iterate thru the vectors and remove any vectors with chip ID that matches the i_chip.
chips.erase(std::remove_if(chips.begin(), chips.end(), prdfCompareChipIds(i_pChipHandle)), chips.end());
}
+
+} // end namespace PRDF
+
diff --git a/src/usr/diag/prdf/common/framework/config/iipDomainContainer.h b/src/usr/diag/prdf/common/framework/config/iipDomainContainer.h
index 223fb8120..36f2d8850 100755
--- a/src/usr/diag/prdf/common/framework/config/iipDomainContainer.h
+++ b/src/usr/diag/prdf/common/framework/config/iipDomainContainer.h
@@ -30,6 +30,9 @@
#include <vector>
+namespace PRDF
+{
+
// Forward References
struct STEP_CODE_DATA_STRUCT;
@@ -256,6 +259,8 @@ private:
};
+} // end namespace PRDF
+
#include "iipDomainContainer.inl"
//#ifdef RS6000 -- changed for V4R1 Bali - 2/27/96 JFP
diff --git a/src/usr/diag/prdf/common/framework/config/iipDomainContainer.inl b/src/usr/diag/prdf/common/framework/config/iipDomainContainer.inl
index effca23b3..be75887ac 100755
--- a/src/usr/diag/prdf/common/framework/config/iipDomainContainer.inl
+++ b/src/usr/diag/prdf/common/framework/config/iipDomainContainer.inl
@@ -24,6 +24,8 @@
#ifndef iipDomainContainer_inl
#define iipDomainContainer_inl
+namespace PRDF
+{
template<class T>
inline
@@ -53,5 +55,7 @@ uint32_t DomainContainer<T>::GetSize(void) const
return(chips.size());
}
+} // end namespace PRDF
+
#endif
diff --git a/src/usr/diag/prdf/common/framework/config/iipSystem.h b/src/usr/diag/prdf/common/framework/config/iipSystem.h
index 23f84e4da..b608b377f 100755
--- a/src/usr/diag/prdf/common/framework/config/iipSystem.h
+++ b/src/usr/diag/prdf/common/framework/config/iipSystem.h
@@ -90,6 +90,9 @@
#include <iipsdbug.h> // Include file for ATTENTION_TYPE
+namespace PRDF
+{
+
// Forward Declarations
class CHIP_CLASS;
class Domain;
@@ -308,5 +311,6 @@ class System
Resolution & noAttnResolution;
};
+} // end namespace PRDF
#endif
diff --git a/src/usr/diag/prdf/common/framework/config/iipchip.C b/src/usr/diag/prdf/common/framework/config/iipchip.C
index 78e1ed378..d5c2187fd 100755
--- a/src/usr/diag/prdf/common/framework/config/iipchip.C
+++ b/src/usr/diag/prdf/common/framework/config/iipchip.C
@@ -60,6 +60,9 @@
#include <iipchip.h>
#include <prdfPlatServices.H>
+namespace PRDF
+{
+
/*--------------------------------------------------------------------*/
/* Forward References */
/*--------------------------------------------------------------------*/
@@ -138,9 +141,11 @@ int32_t CHIP_CLASS::Initialize
return(SUCCESS);
}
-PRDF::HUID CHIP_CLASS::GetId() const
+HUID CHIP_CLASS::GetId() const
{
- return(PRDF::PlatServices::getHuid(iv_pchipHandle));
+ return(PlatServices::getHuid(iv_pchipHandle));
}
+} // end namespace PRDF
+
#undef IIPCHIP_CPP
diff --git a/src/usr/diag/prdf/common/framework/config/iipchip.h b/src/usr/diag/prdf/common/framework/config/iipchip.h
index e45adb0d5..51f0ce3b2 100755
--- a/src/usr/diag/prdf/common/framework/config/iipchip.h
+++ b/src/usr/diag/prdf/common/framework/config/iipchip.h
@@ -49,6 +49,9 @@
/* Forward References */
/*--------------------------------------------------------------------*/
+namespace PRDF
+{
+
class STEP_CODE_DATA_STRUCT;
class CaptureData;
@@ -181,7 +184,7 @@ class CHIP_CLASS
<br><b>Notes: </b> default is to do nothing
</ul><br>
*/
- PRDF::HUID GetId() const;
+ HUID GetId() const;
protected:
@@ -239,4 +242,6 @@ class CHIP_CLASS
};
+} // end namespace PRDF
+
#endif
diff --git a/src/usr/diag/prdf/common/framework/config/prdfExDomain.H b/src/usr/diag/prdf/common/framework/config/prdfExDomain.H
index 0849affb4..964aa87a1 100644
--- a/src/usr/diag/prdf/common/framework/config/prdfExDomain.H
+++ b/src/usr/diag/prdf/common/framework/config/prdfExDomain.H
@@ -26,7 +26,10 @@
#include <prdfRuleChipDomain.H>
-class PrdfExDomain : public PrdfRuleChipDomain
+namespace PRDF
+{
+
+class ExDomain : public RuleChipDomain
{
public:
@@ -35,8 +38,8 @@ class PrdfExDomain : public PrdfRuleChipDomain
* @param i_did The domain ID
* @param i_size The projected size of the domain
*/
- PrdfExDomain( DOMAIN_ID i_did, uint32_t i_size = EX_DOMAIN_SIZE ) :
- PrdfRuleChipDomain( i_did, i_size )
+ ExDomain( DOMAIN_ID i_did, uint32_t i_size = EX_DOMAIN_SIZE ) :
+ RuleChipDomain( i_did, i_size )
{}
/**
@@ -51,5 +54,7 @@ class PrdfExDomain : public PrdfRuleChipDomain
};
+} // end namespace PRDF
+
#endif /* __PRDFEXDOMAIN_H */
diff --git a/src/usr/diag/prdf/common/framework/config/prdfExtensibleChip.H b/src/usr/diag/prdf/common/framework/config/prdfExtensibleChip.H
index 01f17c0eb..8a5e8d4eb 100755
--- a/src/usr/diag/prdf/common/framework/config/prdfExtensibleChip.H
+++ b/src/usr/diag/prdf/common/framework/config/prdfExtensibleChip.H
@@ -29,16 +29,19 @@
#include <prdfPluginDef.H>
-class PrdfDataBundle;
+namespace PRDF
+{
+
+class DataBundle;
-class PrdfExtensibleChip : public CHIP_CLASS
+class ExtensibleChip : public CHIP_CLASS
{
public:
- PrdfExtensibleChip( TARGETING::TargetHandle_t i_target ) :
+ ExtensibleChip( TARGETING::TargetHandle_t i_target ) :
CHIP_CLASS(i_target)
{}
- virtual PrdfExtensibleChipFunction * getExtensibleFunction(
+ virtual ExtensibleChipFunction * getExtensibleFunction(
const char * i_func,
bool i_expectNull = false ) = 0;
@@ -46,7 +49,7 @@ class PrdfExtensibleChip : public CHIP_CLASS
const char * i_reg,
bool i_expectNull = false ) = 0;
- virtual PrdfDataBundle *& getDataBundle() = 0;
+ virtual DataBundle *& getDataBundle() = 0;
/**
* Add Capture data to the Capture Data object
@@ -58,11 +61,13 @@ class PrdfExtensibleChip : public CHIP_CLASS
virtual uint32_t getSignatureOffset() const = 0;
};
-class PrdfDataBundle
+class DataBundle
{
public:
- virtual ~PrdfDataBundle() {};
+ virtual ~DataBundle() {};
};
+} // end namespace PRDF
+
#endif
diff --git a/src/usr/diag/prdf/common/framework/config/prdfExtensibleDomain.C b/src/usr/diag/prdf/common/framework/config/prdfExtensibleDomain.C
index ef6991896..31e03a513 100755
--- a/src/usr/diag/prdf/common/framework/config/prdfExtensibleDomain.C
+++ b/src/usr/diag/prdf/common/framework/config/prdfExtensibleDomain.C
@@ -30,15 +30,18 @@
#include <prdfPfa5Data.h>
#include <iipglobl.h>
-PrdfExtensibleDomainFunction *
- PrdfExtensibleDomain::getExtensibleFunction(const char * i_func,
+namespace PRDF
+{
+
+ExtensibleDomainFunction *
+ ExtensibleDomain::getExtensibleFunction(const char * i_func,
bool i_expectNull)
{
- PrdfExtensibleFunctionType * plugin =
- prdfGetPluginGlobalMap().getPlugins(iv_domainName)[i_func];
+ ExtensibleFunctionType * plugin =
+ getPluginGlobalMap().getPlugins(iv_domainName)[i_func];
if (NULL == plugin)
{
- static PrdfPlugin<PrdfExtensibleDomain> l_nullPlugin(NULL);
+ static Plugin<ExtensibleDomain> l_nullPlugin(NULL);
plugin = &l_nullPlugin;
if (!i_expectNull)
@@ -57,19 +60,22 @@ PrdfExtensibleDomainFunction *
PRDF_ADD_FFDC(l_errl,
iv_domainName,
strlen(iv_domainName),
- prdfErrlVer1,
- prdfErrlString);
+ ErrlVer1,
+ ErrlString);
PRDF_ADD_FFDC(l_errl,
i_func,
strlen(i_func),
- prdfErrlVer1,
- prdfErrlString);
+ ErrlVer1,
+ ErrlString);
PRDF_COMMIT_ERRL(l_errl, ERRL_ACTION_REPORT);
delete l_errl;
}
}
- return (PrdfExtensibleDomainFunction *) plugin;
+ return (ExtensibleDomainFunction *) plugin;
}
+
+} // end namespace PRDF
+
diff --git a/src/usr/diag/prdf/common/framework/config/prdfExtensibleDomain.H b/src/usr/diag/prdf/common/framework/config/prdfExtensibleDomain.H
index b37f60c9e..9432a5ad2 100755
--- a/src/usr/diag/prdf/common/framework/config/prdfExtensibleDomain.H
+++ b/src/usr/diag/prdf/common/framework/config/prdfExtensibleDomain.H
@@ -27,13 +27,16 @@
#include <prdfPluginDef.H>
#include <prdfExtensibleChip.H>
-class PrdfExtensibleDomain
+namespace PRDF
+{
+
+class ExtensibleDomain
{
public:
- PrdfExtensibleDomain(const char * i_domainName) :
+ ExtensibleDomain(const char * i_domainName) :
iv_domainName(i_domainName), iv_dataBundle(NULL) {};
- virtual ~PrdfExtensibleDomain()
+ virtual ~ExtensibleDomain()
{
if (NULL != iv_dataBundle)
{
@@ -42,16 +45,18 @@ class PrdfExtensibleDomain
}
};
- virtual PrdfExtensibleDomainFunction *
+ virtual ExtensibleDomainFunction *
getExtensibleFunction(const char * i_func,
bool i_expectNull = false);
- virtual PrdfDataBundle *& getDataBundle() { return iv_dataBundle; };
+ virtual DataBundle *& getDataBundle() { return iv_dataBundle; };
private:
const char * iv_domainName;
- PrdfDataBundle * iv_dataBundle;
+ DataBundle * iv_dataBundle;
};
+} // end namespace PRDF
+
#endif //__PRDFEXTENSIBLEDOMAIN_H
diff --git a/src/usr/diag/prdf/common/framework/config/prdfFabricDomain.C b/src/usr/diag/prdf/common/framework/config/prdfFabricDomain.C
index e01d38c02..1efef0eb9 100755
--- a/src/usr/diag/prdf/common/framework/config/prdfFabricDomain.C
+++ b/src/usr/diag/prdf/common/framework/config/prdfFabricDomain.C
@@ -46,6 +46,8 @@
#include <algorithm>
#undef prdfFabricDomain_C
+namespace PRDF
+{
//----------------------------------------------------------------------
// User Types
//----------------------------------------------------------------------
@@ -72,10 +74,8 @@
int32_t FabricDomain::Analyze(STEP_CODE_DATA_STRUCT & serviceData,
ATTENTION_TYPE attentionType)
{
- using namespace PRDF;
-
int32_t l_rc;
- l_rc = DomainContainer<PrdfRuleChip>::Analyze(serviceData, attentionType);
+ l_rc = DomainContainer<RuleChip>::Analyze(serviceData, attentionType);
if( l_rc == PRD_POWER_FAULT )
@@ -108,8 +108,7 @@ int32_t FabricDomain::Analyze(STEP_CODE_DATA_STRUCT & serviceData,
void FabricDomain::Order(ATTENTION_TYPE attentionType)
{
- using namespace PRDF;
- using PrdfPluginDef::bindParm;
+ using PluginDef::bindParm;
if (attentionType == MACHINE_CHECK)
{
@@ -125,7 +124,7 @@ void FabricDomain::Order(ATTENTION_TYPE attentionType)
SYSTEM_DEBUG_CLASS sysdbug;
for (int32_t i = (GetSize() - 1); i >= 0; --i) //pw03
{
- PrdfRuleChip * l_fabChip = LookUp(i);
+ RuleChip * l_fabChip = LookUp(i);
TARGETING::TargetHandle_t l_pchipHandle = l_fabChip->GetChipHandle();
if ((sysdbug.IsAttentionActive(l_pchipHandle)) &&
(sysdbug.GetAttentionType(l_pchipHandle ) == attentionType))
@@ -143,7 +142,7 @@ void FabricDomain::Order(ATTENTION_TYPE attentionType)
// 3. WOF/TOD counters
void FabricDomain::SortForXstop()
{
- using namespace PrdfPluginDef;
+ using namespace PluginDef;
using namespace TARGETING;
uint32_t l_internalOnlyCount = 0;
@@ -161,14 +160,14 @@ void FabricDomain::SortForXstop()
l_externalDrivers[i] = 0;
l_wofValues[i] = 0;
- PrdfRuleChip * l_fabChip = LookUp(i);
+ RuleChip * l_fabChip = LookUp(i);
ptr.u = &l_externalDrivers[i]; // zs01
- prdfBitString l_externalChips(GetSize(), ptr.c); // zs01
+ BitString l_externalChips(GetSize(), ptr.c); // zs01
TargetHandleList l_tmpList;
// Call "GetCheckstopInfo" plugin.
- PrdfExtensibleChipFunction * l_extFunc
+ ExtensibleChipFunction * l_extFunc
= l_fabChip->getExtensibleFunction("GetCheckstopInfo");
(*l_extFunc)(l_fabChip,
@@ -232,7 +231,7 @@ void FabricDomain::SortForXstop()
for (uint32_t j = 0; j < GetSize(); j++)
{
ptr.u = &l_externalDrivers[i]; // zs01
- if ( prdfBitString(GetSize(), ptr.c).IsSet(j) ) // zs01
+ if ( BitString(GetSize(), ptr.c).IsSet(j) ) // zs01
l_current.Set(j);
}
}
@@ -284,8 +283,7 @@ namespace __prdfFabricDomain // pw03 ---
void FabricDomain::SortForRecov()
{
- using namespace PRDF;
- using namespace PrdfPluginDef;
+ using namespace PluginDef;
SYSTEM_DEBUG_CLASS sysdbug;
uint32_t l_sev[GetSize()];
@@ -294,7 +292,7 @@ void FabricDomain::SortForRecov()
// Loop through all chips.
for (uint32_t i = 0; i < GetSize(); ++i)
{
- PrdfRuleChip * l_fabChip = LookUp(i);
+ RuleChip * l_fabChip = LookUp(i);
TARGETING::TargetHandle_t l_pchipHandle = l_fabChip->GetChipHandle();
if (sysdbug.IsAttentionActive(l_pchipHandle)) // If at attention, check.
{
@@ -307,7 +305,7 @@ void FabricDomain::SortForRecov()
else if (CHECK_STOP == sysdbug.GetAttentionType(l_pchipHandle))
{
// Check for recovered error at checkstop.
- PrdfExtensibleChipFunction * l_extFunc
+ ExtensibleChipFunction * l_extFunc
= l_fabChip->getExtensibleFunction("CheckForRecovered");
bool l_hasRer = false;
@@ -324,7 +322,7 @@ void FabricDomain::SortForRecov()
// Find real severity level.
if (0 != l_sev[i])
{
- PrdfExtensibleChipFunction * l_extFunc
+ ExtensibleChipFunction * l_extFunc
= l_fabChip->getExtensibleFunction(
"CheckForRecoveredSev");
@@ -363,7 +361,7 @@ int32_t FabricDomain::AnalyzeTheseChips(STEP_CODE_DATA_STRUCT & serviceData,
for (TargetHandleList::iterator i = i_chips.begin(); i != i_chips.end(); ++i)
{
PRDF_DTRAC( "FabricDomain::AnalyzeTheseChips::Before--chip=0x%X",
- PRDF::PlatServices::getHuid(*i));
+ PlatServices::getHuid(*i));
}
OrderTheseChips(attentionType, i_chips);
@@ -371,11 +369,11 @@ int32_t FabricDomain::AnalyzeTheseChips(STEP_CODE_DATA_STRUCT & serviceData,
for (TargetHandleList::iterator i = i_chips.begin(); i != i_chips.end(); ++i)
{
PRDF_DTRAC( "FabricDomain::AnalyzeTheseChips::After--chip=0x%X",
- PRDF::PlatServices::getHuid(*i) );
+ PlatServices::getHuid(*i) );
}
//After the Order function is called the first chip should contain the chip to look at.
//Look here for the correct LookUp function. I don't think this is working.
- PrdfRuleChip * l_fabChip = FindChipInTheseChips(i_chips[0], i_chips);
+ RuleChip * l_fabChip = FindChipInTheseChips(i_chips[0], i_chips);
PRDF_DTRAC( "FabricDomain::AnalyzeTheseChips::Analyzing this one: 0x%X",
l_fabChip->GetId() );
if(NULL != l_fabChip)
@@ -397,7 +395,7 @@ int32_t FabricDomain::AnalyzeTheseChips(STEP_CODE_DATA_STRUCT & serviceData,
//Get P7 chip Global FIR data for FFDC
for (TargetHandleList::iterator i = i_chips.begin(); i != i_chips.end(); ++i)
{
- PrdfRuleChip * l_fabChip = FindChipInTheseChips(*i, i_chips);
+ RuleChip * l_fabChip = FindChipInTheseChips(*i, i_chips);
l_fabChip->CaptureErrorData(
serviceData.service_data->GetCaptureData(),
Util::hashString("GlobalFIRs"));
@@ -412,7 +410,7 @@ int32_t FabricDomain::AnalyzeTheseChips(STEP_CODE_DATA_STRUCT & serviceData,
int32_t FabricDomain::OrderTheseChips(ATTENTION_TYPE attentionType,
TARGETING::TargetHandleList & i_chips)
{
- using namespace PrdfPluginDef;
+ using namespace PluginDef;
using namespace TARGETING;
PRDF_DENTER( "FabricDomain::OrderTheseChips" );
@@ -429,16 +427,16 @@ int32_t FabricDomain::OrderTheseChips(ATTENTION_TYPE attentionType,
for (TargetHandleList::iterator i = i_chips.begin(); i != i_chips.end(); ++i)
{
- PrdfRuleChip * l_fabChip = FindChipInTheseChips(*i, i_chips);
+ RuleChip * l_fabChip = FindChipInTheseChips(*i, i_chips);
ptr.u = &l_externalDrivers[l_chip];
- prdfBitString l_externalChips(i_chips.size(), ptr.c);
+ BitString l_externalChips(i_chips.size(), ptr.c);
TargetHandleList l_tmpList;
if(l_fabChip != NULL)
{
// Call "GetCheckstopInfo" plugin.
- PrdfExtensibleChipFunction * l_extFunc
+ ExtensibleChipFunction * l_extFunc
= l_fabChip->getExtensibleFunction("GetCheckstopInfo");
(*l_extFunc)(l_fabChip,
@@ -489,12 +487,12 @@ int32_t FabricDomain::OrderTheseChips(ATTENTION_TYPE attentionType,
//This function is to ensure the order of the chip in the list is the correct chip.
//Because there is no garaunteed order within the domain container this is necessary.
-PrdfRuleChip * FabricDomain::FindChipInTheseChips(TARGETING::TargetHandle_t i_pchipHandle, TARGETING::TargetHandleList & i_chips)
+RuleChip * FabricDomain::FindChipInTheseChips(TARGETING::TargetHandle_t i_pchipHandle, TARGETING::TargetHandleList & i_chips)
{
using namespace TARGETING;
PRDF_DENTER( "FabricDomain::FindChipNumber" );
- PrdfRuleChip * l_fabChip = NULL;
+ RuleChip * l_fabChip = NULL;
TargetHandle_t l_tmpfabHandle= NULL;
// Loop through all chips.
for (TargetHandleList::iterator iter = i_chips.begin(); iter != i_chips.end(); ++iter)
@@ -521,3 +519,5 @@ void FabricDomain::MoveToFrontInTheseChips(uint32_t i_chipToFront, TARGETING::Ta
std::swap((*i), (*(i-1)));
}
}
+
+} //End namespace PRDF
diff --git a/src/usr/diag/prdf/common/framework/config/prdfFabricDomain.H b/src/usr/diag/prdf/common/framework/config/prdfFabricDomain.H
index 645daac21..c5e3cd5fb 100755
--- a/src/usr/diag/prdf/common/framework/config/prdfFabricDomain.H
+++ b/src/usr/diag/prdf/common/framework/config/prdfFabricDomain.H
@@ -42,7 +42,11 @@
@brief Fabric Domain, contains Fabric Chips
@author Mike Kobler
*/
-class FabricDomain : public PrdfRuleChipDomain
+
+namespace PRDF
+{
+
+class FabricDomain : public RuleChipDomain
{
public:
@@ -52,7 +56,7 @@ class FabricDomain : public PrdfRuleChipDomain
* @param i_size The projected size of the domain
*/
FabricDomain( DOMAIN_ID i_did, uint32_t i_size = PROC_DOMAIN_SIZE ) :
- PrdfRuleChipDomain( i_did, i_size )
+ RuleChipDomain( i_did, i_size )
{}
/*
@@ -113,8 +117,8 @@ class FabricDomain : public PrdfRuleChipDomain
* @param i_chips List of chips in the domain to analyze.
* @return SUCCESS
*/
- virtual PrdfRuleChip * FindChipInTheseChips( TARGETING::TargetHandle_t i_chipId,
- TARGETING::TargetHandleList & i_chips );
+ virtual RuleChip * FindChipInTheseChips( TARGETING::TargetHandle_t i_chipId,
+ TARGETING::TargetHandleList & i_chips );
/**
* @brief Moves the chip in question to the front of the list of chips.
@@ -160,4 +164,6 @@ private: // Data
};
+} // end namespace PRDF
+
#endif /* prdfFabricDomain_H */
diff --git a/src/usr/diag/prdf/common/framework/config/prdfMbaDomain.H b/src/usr/diag/prdf/common/framework/config/prdfMbaDomain.H
index 3b98351c5..d2220b3d4 100644
--- a/src/usr/diag/prdf/common/framework/config/prdfMbaDomain.H
+++ b/src/usr/diag/prdf/common/framework/config/prdfMbaDomain.H
@@ -26,7 +26,10 @@
#include <prdfRuleChipDomain.H>
-class PrdfMbaDomain : public PrdfRuleChipDomain
+namespace PRDF
+{
+
+class MbaDomain : public RuleChipDomain
{
public:
@@ -35,8 +38,8 @@ class PrdfMbaDomain : public PrdfRuleChipDomain
* @param i_did The domain ID
* @param i_size The projected size of the domain
*/
- PrdfMbaDomain( DOMAIN_ID i_did, uint32_t i_size = MBA_DOMAIN_SIZE ) :
- PrdfRuleChipDomain( i_did, i_size )
+ MbaDomain( DOMAIN_ID i_did, uint32_t i_size = MBA_DOMAIN_SIZE ) :
+ RuleChipDomain( i_did, i_size )
{}
/**
@@ -51,5 +54,7 @@ class PrdfMbaDomain : public PrdfRuleChipDomain
};
+} // end namespace PRDF
+
#endif /* __PRDFMBADOMAIN_H */
diff --git a/src/usr/diag/prdf/common/framework/config/prdfMcsDomain.H b/src/usr/diag/prdf/common/framework/config/prdfMcsDomain.H
index 60cdb5f21..341ecc706 100644
--- a/src/usr/diag/prdf/common/framework/config/prdfMcsDomain.H
+++ b/src/usr/diag/prdf/common/framework/config/prdfMcsDomain.H
@@ -26,7 +26,10 @@
#include <prdfRuleChipDomain.H>
-class PrdfMcsDomain : public PrdfRuleChipDomain
+namespace PRDF
+{
+
+class McsDomain : public RuleChipDomain
{
public:
@@ -35,8 +38,8 @@ class PrdfMcsDomain : public PrdfRuleChipDomain
* @param i_did The domain ID
* @param i_size The projected size of the domain
*/
- PrdfMcsDomain( DOMAIN_ID i_did, uint32_t i_size = MCS_DOMAIN_SIZE ) :
- PrdfRuleChipDomain( i_did, i_size )
+ McsDomain( DOMAIN_ID i_did, uint32_t i_size = MCS_DOMAIN_SIZE ) :
+ RuleChipDomain( i_did, i_size )
{}
/**
@@ -51,5 +54,7 @@ class PrdfMcsDomain : public PrdfRuleChipDomain
};
+} // end namespace PRDF
+
#endif /* __PRDFMCSDOMAIN_H */
diff --git a/src/usr/diag/prdf/common/framework/config/prdfMembufDomain.H b/src/usr/diag/prdf/common/framework/config/prdfMembufDomain.H
index df4f08970..ca2b9be81 100644
--- a/src/usr/diag/prdf/common/framework/config/prdfMembufDomain.H
+++ b/src/usr/diag/prdf/common/framework/config/prdfMembufDomain.H
@@ -26,7 +26,10 @@
#include <prdfRuleChipDomain.H>
-class PrdfMembufDomain : public PrdfRuleChipDomain
+namespace PRDF
+{
+
+class MembufDomain : public RuleChipDomain
{
public:
@@ -35,11 +38,13 @@ class PrdfMembufDomain : public PrdfRuleChipDomain
* @param i_did The domain ID
* @param i_size The projected size of the domain
*/
- PrdfMembufDomain( DOMAIN_ID i_did, uint32_t i_size = MEMBUF_DOMAIN_SIZE ) :
- PrdfRuleChipDomain( i_did, i_size )
+ MembufDomain( DOMAIN_ID i_did, uint32_t i_size = MEMBUF_DOMAIN_SIZE ) :
+ RuleChipDomain( i_did, i_size )
{}
};
+} // end namespace PRDF
+
#endif /* __PRDFMEMBUFDOMAIN_H */
diff --git a/src/usr/diag/prdf/common/framework/config/prdfParentDomain.C b/src/usr/diag/prdf/common/framework/config/prdfParentDomain.C
index 83c46a7ed..14759cef6 100755
--- a/src/usr/diag/prdf/common/framework/config/prdfParentDomain.C
+++ b/src/usr/diag/prdf/common/framework/config/prdfParentDomain.C
@@ -64,6 +64,8 @@
// Member Function Specifications
//---------------------------------------------------------------------
+namespace PRDF
+{
//Constructor
template<class T>
@@ -102,5 +104,6 @@ typename ParentDomain<T>::iterator ParentDomain<T>::getEndIterator()
//This instance of ParentDomain has to remain after the definition
// of the Templated class function or it won't link correctly.
-template class ParentDomain<PrdfExtensibleDomain>;
+template class ParentDomain<ExtensibleDomain>;
+} // end namespace PRDF
diff --git a/src/usr/diag/prdf/common/framework/config/prdfParentDomain.H b/src/usr/diag/prdf/common/framework/config/prdfParentDomain.H
index 79ef13097..8981ed56f 100755
--- a/src/usr/diag/prdf/common/framework/config/prdfParentDomain.H
+++ b/src/usr/diag/prdf/common/framework/config/prdfParentDomain.H
@@ -27,6 +27,8 @@
#include <prdfRuleChip.H>
#include <vector>
+namespace PRDF
+{
/**
Template class that Define a domain Parent that contain other domains as children.
@par
@@ -126,4 +128,6 @@ private:
};
+} // end namespace PRDF
+
#endif
diff --git a/src/usr/diag/prdf/common/framework/config/prdfPllDomain.C b/src/usr/diag/prdf/common/framework/config/prdfPllDomain.C
index 3acd6c45c..1076df31c 100755
--- a/src/usr/diag/prdf/common/framework/config/prdfPllDomain.C
+++ b/src/usr/diag/prdf/common/framework/config/prdfPllDomain.C
@@ -54,15 +54,15 @@ int32_t PllDomain::Initialize(void)
//However, the inits from other comps are better are cleaning up the PLL errors.
// for (unsigned int i = 0; i < GetSize() && rc == SUCCESS; ++i)
// {
-// PrdfExtensibleChip * l_chip = LookUp(i);
-// PrdfExtensibleFunction * l_clearPll = l_chip->getExtensibleFunction("ClearPll");
+// ExtensibleChip * l_chip = LookUp(i);
+// ExtensibleFunction * l_clearPll = l_chip->getExtensibleFunction("ClearPll");
// Call ClearPll on this chip (see prdfPluginDef.H for bindParm defn)
-// (*l_clearPll)(l_chip,PrdfPluginDef::bindParm<void *>(NULL));
+// (*l_clearPll)(l_chip,PluginDef::bindParm<void *>(NULL));
//@jl01 D-END
// Don't unmask 04/20/2006 Review
-// PrdfExtensibleFunction * l_unmask = l_chip->getExtensibleFunction("UnmaskPll");
-// (*l_unmask)(l_chip,PrdfPluginDef::bindParm<void *>(NULL));
+// ExtensibleFunction * l_unmask = l_chip->getExtensibleFunction("UnmaskPll");
+// (*l_unmask)(l_chip,PluginDef::bindParm<void *>(NULL));
// }
}
return(rc);
@@ -84,10 +84,10 @@ bool PllDomain::Query(ATTENTION_TYPE attentionType)
{
if(sysdbug.IsAttentionActive(LookUp(index)->GetChipHandle()))
{
- PrdfExtensibleChip * l_chip = LookUp(index);
- PrdfExtensibleChipFunction * l_query =
+ ExtensibleChip * l_chip = LookUp(index);
+ ExtensibleChipFunction * l_query =
l_chip->getExtensibleFunction("QueryPll");
- int32_t rc = (*l_query)(l_chip,PrdfPluginDef::bindParm<bool &>(atAttn));
+ int32_t rc = (*l_query)(l_chip,PluginDef::bindParm<bool &>(atAttn));
// if rc then scom read failed - Error log has already been generated
if( PRD_POWER_FAULT == rc )
{
@@ -110,7 +110,7 @@ bool PllDomain::Query(ATTENTION_TYPE attentionType)
int32_t PllDomain::Analyze(STEP_CODE_DATA_STRUCT & serviceData,
ATTENTION_TYPE attentionType)
{
- typedef PrdfExtensibleChip * ChipPtr;
+ typedef ExtensibleChip * ChipPtr;
CcAutoDeletePointerVector<ChipPtr> chip(new ChipPtr[GetSize()]);
int count = 0;
int32_t rc = SUCCESS;
@@ -118,16 +118,16 @@ int32_t PllDomain::Analyze(STEP_CODE_DATA_STRUCT & serviceData,
// Due to clock issues some chips may be moved to non-functional during
// analysis. In this case, these chips will need to be removed from their
// domains.
- typedef std::vector<PrdfExtensibleChip *> NonFuncChips;
+ typedef std::vector<ExtensibleChip *> NonFuncChips;
NonFuncChips nfchips;
// Count # of chips that had PLL error
for(unsigned int index = 0; index < GetSize(); ++index)
{
- PrdfExtensibleChip * l_chip = LookUp(index);
- PrdfExtensibleChipFunction * l_query = l_chip->getExtensibleFunction("QueryPll");
+ ExtensibleChip * l_chip = LookUp(index);
+ ExtensibleChipFunction * l_query = l_chip->getExtensibleFunction("QueryPll");
bool atAttn;
- rc = (*l_query)(l_chip,PrdfPluginDef::bindParm<bool &>(atAttn));
+ rc = (*l_query)(l_chip,PluginDef::bindParm<bool &>(atAttn));
if(atAttn == true)
{
chip()[count] = LookUp(index);
@@ -160,12 +160,12 @@ int32_t PllDomain::Analyze(STEP_CODE_DATA_STRUCT & serviceData,
const uint32_t tmpCount = serviceData.service_data->GetMruList().size();
// Call this chip's CalloutPll plugin if it exists.
- PrdfExtensibleChipFunction * l_callout =
+ ExtensibleChipFunction * l_callout =
chip()[0]->getExtensibleFunction( "CalloutPll", true );
if ( NULL != l_callout )
{
(*l_callout)( chip()[0],
- PrdfPluginDef::bindParm<STEP_CODE_DATA_STRUCT &>(serviceData) );
+ PluginDef::bindParm<STEP_CODE_DATA_STRUCT &>(serviceData) );
}
if ( tmpCount == serviceData.service_data->GetMruList().size() )
@@ -180,9 +180,9 @@ int32_t PllDomain::Analyze(STEP_CODE_DATA_STRUCT & serviceData,
if(serviceData.service_data->IsAtThreshold())
{
// Mask in all chips in domain
- PrdfExtensibleDomainFunction * l_mask = getExtensibleFunction("MaskPll");
+ ExtensibleDomainFunction * l_mask = getExtensibleFunction("MaskPll");
(*l_mask)(this,
- PrdfPluginDef::bindParm<STEP_CODE_DATA_STRUCT&>(serviceData));
+ PluginDef::bindParm<STEP_CODE_DATA_STRUCT&>(serviceData));
}
// Set Signature
serviceData.service_data->GetErrorSignature()->setChipId(chip()[0]->GetId());
@@ -194,19 +194,19 @@ int32_t PllDomain::Analyze(STEP_CODE_DATA_STRUCT & serviceData,
#endif
// Clear PLLs from this domain.
- PrdfExtensibleDomainFunction * l_clear = getExtensibleFunction("ClearPll");
+ ExtensibleDomainFunction * l_clear = getExtensibleFunction("ClearPll");
(*l_clear)(this,
- PrdfPluginDef::bindParm<STEP_CODE_DATA_STRUCT&>(serviceData));
+ PluginDef::bindParm<STEP_CODE_DATA_STRUCT&>(serviceData));
// Run any PLL Post Analysis functions from this domain.
for(int i = 0; i < count; i++)
{
- PrdfExtensibleChip * l_chip = chip()[i];
+ ExtensibleChip * l_chip = chip()[i];
// Send any special messages indicating there was a PLL error.
- PrdfExtensibleChipFunction * l_pllPostAnalysis =
+ ExtensibleChipFunction * l_pllPostAnalysis =
l_chip->getExtensibleFunction("PllPostAnalysis", true);
(*l_pllPostAnalysis)(l_chip,
- PrdfPluginDef::bindParm<STEP_CODE_DATA_STRUCT&>(serviceData));
+ PluginDef::bindParm<STEP_CODE_DATA_STRUCT&>(serviceData));
}
return rc;
@@ -221,7 +221,7 @@ void PllDomain::Order(ATTENTION_TYPE attentionType)
//------------------------------------------------------------------------------
-int32_t PllDomain::ClearPll( PrdfExtensibleDomain * i_domain,
+int32_t PllDomain::ClearPll( ExtensibleDomain * i_domain,
STEP_CODE_DATA_STRUCT i_sc )
{
PllDomain * l_domain = (PllDomain *) i_domain;
@@ -229,23 +229,23 @@ int32_t PllDomain::ClearPll( PrdfExtensibleDomain * i_domain,
// Clear children chips.
for ( uint32_t i = 0; i < l_domain->GetSize(); i++ )
{
- PrdfExtensibleChip * l_chip = l_domain->LookUp(i);
- PrdfExtensibleChipFunction * l_clear =
+ ExtensibleChip * l_chip = l_domain->LookUp(i);
+ ExtensibleChipFunction * l_clear =
l_chip->getExtensibleFunction("ClearPll");
(*l_clear)( l_chip,
- PrdfPluginDef::bindParm<STEP_CODE_DATA_STRUCT&>(i_sc) );
+ PluginDef::bindParm<STEP_CODE_DATA_STRUCT&>(i_sc) );
}
// Clear children domains.
// This looks like a recursive call. It calls other domains of Clear.
- ParentDomain<PrdfExtensibleDomain>::iterator i;
+ ParentDomain<ExtensibleDomain>::iterator i;
for (i = l_domain->getBeginIterator(); i != l_domain->getEndIterator(); i++)
{
// Clear PLLs from this domain.
- PrdfExtensibleDomainFunction * l_clear =
+ ExtensibleDomainFunction * l_clear =
(i->second)->getExtensibleFunction("ClearPll");
(*l_clear)( i->second,
- PrdfPluginDef::bindParm<STEP_CODE_DATA_STRUCT&>(i_sc) );
+ PluginDef::bindParm<STEP_CODE_DATA_STRUCT&>(i_sc) );
}
return SUCCESS;
@@ -254,7 +254,7 @@ PRDF_PLUGIN_DEFINE( PllDomain, ClearPll );
//------------------------------------------------------------------------------
-int32_t PllDomain::MaskPll( PrdfExtensibleDomain * i_domain,
+int32_t PllDomain::MaskPll( ExtensibleDomain * i_domain,
STEP_CODE_DATA_STRUCT i_sc )
{
PllDomain * l_domain = (PllDomain *) i_domain;
@@ -262,22 +262,22 @@ int32_t PllDomain::MaskPll( PrdfExtensibleDomain * i_domain,
// Mask children chips.
for ( uint32_t i = 0; i < l_domain->GetSize(); i++ )
{
- PrdfExtensibleChip * l_chip = l_domain->LookUp(i);
- PrdfExtensibleChipFunction * l_mask =
+ ExtensibleChip * l_chip = l_domain->LookUp(i);
+ ExtensibleChipFunction * l_mask =
l_chip->getExtensibleFunction("MaskPll");
(*l_mask)( l_chip,
- PrdfPluginDef::bindParm<STEP_CODE_DATA_STRUCT&>(i_sc) );
+ PluginDef::bindParm<STEP_CODE_DATA_STRUCT&>(i_sc) );
}
// Mask children domains.
// This looks like a recursive call. It calls other domains of Mask.
- ParentDomain<PrdfExtensibleDomain>::iterator i;
+ ParentDomain<ExtensibleDomain>::iterator i;
for (i = l_domain->getBeginIterator(); i != l_domain->getEndIterator(); i++)
{
- PrdfExtensibleDomainFunction * l_mask =
+ ExtensibleDomainFunction * l_mask =
(i->second)->getExtensibleFunction("MaskPll");
(*l_mask)( i->second,
- PrdfPluginDef::bindParm<STEP_CODE_DATA_STRUCT&>(i_sc) );
+ PluginDef::bindParm<STEP_CODE_DATA_STRUCT&>(i_sc) );
}
return SUCCESS;
diff --git a/src/usr/diag/prdf/common/framework/config/prdfPllDomain.H b/src/usr/diag/prdf/common/framework/config/prdfPllDomain.H
index b5d55a206..583b54c84 100755
--- a/src/usr/diag/prdf/common/framework/config/prdfPllDomain.H
+++ b/src/usr/diag/prdf/common/framework/config/prdfPllDomain.H
@@ -40,8 +40,8 @@ namespace PRDF
//------------------------------------------------------------------------------
-class PllDomain : public PrdfRuleChipDomain, public PrdfExtensibleDomain,
- public ParentDomain<PrdfExtensibleDomain>
+class PllDomain : public RuleChipDomain, public ExtensibleDomain,
+ public ParentDomain<ExtensibleDomain>
{
public:
@@ -106,7 +106,7 @@ class PllDomain : public PrdfRuleChipDomain, public PrdfExtensibleDomain,
* @param i_sc The step code data struct.
* @return SUCCESS
*/
- static int32_t ClearPll( PrdfExtensibleDomain * i_domain,
+ static int32_t ClearPll( ExtensibleDomain * i_domain,
STEP_CODE_DATA_STRUCT i_sc );
/**
@@ -116,7 +116,7 @@ class PllDomain : public PrdfRuleChipDomain, public PrdfExtensibleDomain,
* @param i_sc The step code data struct.
* @return SUCCESS
*/
- static int32_t MaskPll( PrdfExtensibleDomain * i_domain,
+ static int32_t MaskPll( ExtensibleDomain * i_domain,
STEP_CODE_DATA_STRUCT i_sc );
protected:
@@ -152,8 +152,8 @@ private: // Data
inline
PllDomain::PllDomain( DOMAIN_ID domain_id, Resolution & clockSource,
const ThresholdResolution::ThresholdPolicy& i_mfgThresh) :
- PrdfRuleChipDomain( domain_id, PllDomain::CONTAINER_SIZE ),
- PrdfExtensibleDomain("PllDomain"),
+ RuleChipDomain( domain_id, PllDomain::CONTAINER_SIZE ),
+ ExtensibleDomain("PllDomain"),
closeClockSource(clockSource),
farClockSource(clockSource),
iv_threshold( ResolutionFactory::Access().GetThresholdResolution( 1,
@@ -167,8 +167,8 @@ inline
PllDomain::PllDomain( DOMAIN_ID domain_id, Resolution & clockSource,
hwTableContent i_hwdc,
const ThresholdResolution::ThresholdPolicy& i_mfgThresh) :
- PrdfRuleChipDomain( domain_id, PllDomain::CONTAINER_SIZE ),
- PrdfExtensibleDomain("PllDomain"),
+ RuleChipDomain( domain_id, PllDomain::CONTAINER_SIZE ),
+ ExtensibleDomain("PllDomain"),
closeClockSource(clockSource),
farClockSource(clockSource),
iv_threshold( ResolutionFactory::Access().GetThresholdResolution( 1,
diff --git a/src/usr/diag/prdf/common/framework/config/prdfRuleChipDomain.C b/src/usr/diag/prdf/common/framework/config/prdfRuleChipDomain.C
index 212fbe993..04e009657 100755
--- a/src/usr/diag/prdf/common/framework/config/prdfRuleChipDomain.C
+++ b/src/usr/diag/prdf/common/framework/config/prdfRuleChipDomain.C
@@ -31,18 +31,19 @@
//------------------------------------------------------------------------------
-bool PrdfRuleChipDomain::Query( ATTENTION_TYPE i_attnType )
+namespace PRDF
{
- using namespace PRDF;
+bool RuleChipDomain::Query( ATTENTION_TYPE i_attnType )
+{
bool o_rc = false;
- using PrdfPluginDef::bindParm;
+ using PluginDef::bindParm;
SYSTEM_DEBUG_CLASS sysdbug;
for ( uint32_t i = 0; i < GetSize(); i++ )
{
- PrdfRuleChip * chip = LookUp(i);
+ RuleChip * chip = LookUp(i);
TARGETING::TargetHandle_t l_pchipHandle = LookUp(i)->GetChipHandle();
if ( sysdbug.IsAttentionActive(l_pchipHandle) )
@@ -76,7 +77,7 @@ bool PrdfRuleChipDomain::Query( ATTENTION_TYPE i_attnType )
continue;
}
- PrdfExtensibleChipFunction * ef
+ ExtensibleChipFunction * ef
= chip->getExtensibleFunction( funcName, true );
bool ignore = false;
@@ -98,7 +99,7 @@ bool PrdfRuleChipDomain::Query( ATTENTION_TYPE i_attnType )
( (sysdbug.GetAttentionType(l_pchipHandle) == CHECK_STOP) ||
(sysdbug.GetAttentionType(l_pchipHandle) == UNIT_CS) ) )
{
- PrdfExtensibleChipFunction * ef
+ ExtensibleChipFunction * ef
= chip->getExtensibleFunction("CheckForRecovered");
(*ef)(chip, bindParm<bool &>(o_rc));
@@ -112,18 +113,16 @@ bool PrdfRuleChipDomain::Query( ATTENTION_TYPE i_attnType )
//------------------------------------------------------------------------------
-void PrdfRuleChipDomain::Order( ATTENTION_TYPE i_attnType )
+void RuleChipDomain::Order( ATTENTION_TYPE i_attnType )
{
- using namespace PRDF;
-
- using PrdfPluginDef::bindParm;
+ using PluginDef::bindParm;
SYSTEM_DEBUG_CLASS sysdbug;
const char * funcName; //mp01 a
for ( int32_t i = (GetSize() - 1); i >= 0; i-- )
{
- PrdfRuleChip * chip = LookUp(i);
+ RuleChip * chip = LookUp(i);
TARGETING::TargetHandle_t l_pchipHandle = LookUp(i)->GetChipHandle();
if ( sysdbug.IsAttentionActive(l_pchipHandle) )
@@ -156,7 +155,7 @@ void PrdfRuleChipDomain::Order( ATTENTION_TYPE i_attnType )
continue;
}
- PrdfExtensibleChipFunction * ef
+ ExtensibleChipFunction * ef
= chip->getExtensibleFunction( funcName, true );
bool ignore = false;
@@ -177,7 +176,7 @@ void PrdfRuleChipDomain::Order( ATTENTION_TYPE i_attnType )
( (sysdbug.GetAttentionType(l_pchipHandle) == CHECK_STOP) ||
(sysdbug.GetAttentionType(l_pchipHandle) == UNIT_CS) ) )
{
- PrdfExtensibleChipFunction * ef
+ ExtensibleChipFunction * ef
= chip->getExtensibleFunction("CheckForRecovered");
bool hasRer = false;
(*ef)(chip, bindParm<bool &>(hasRer));
@@ -191,3 +190,5 @@ void PrdfRuleChipDomain::Order( ATTENTION_TYPE i_attnType )
}
}
}
+
+} // end namespace PRDF
diff --git a/src/usr/diag/prdf/common/framework/config/prdfRuleChipDomain.H b/src/usr/diag/prdf/common/framework/config/prdfRuleChipDomain.H
index 9b3fb7654..59dde7f35 100755
--- a/src/usr/diag/prdf/common/framework/config/prdfRuleChipDomain.H
+++ b/src/usr/diag/prdf/common/framework/config/prdfRuleChipDomain.H
@@ -27,7 +27,10 @@
#include <iipDomainContainer.h>
#include <prdfRuleChip.H>
-class PrdfRuleChipDomain : public DomainContainer<PrdfRuleChip>
+namespace PRDF
+{
+
+class RuleChipDomain : public DomainContainer<RuleChip>
{
public:
@@ -49,13 +52,13 @@ class PrdfRuleChipDomain : public DomainContainer<PrdfRuleChip>
TOTAL_DOMAINS = 5,
};
- /** @fn PrdfRuleChipDomain
+ /** @fn RuleChipDomain
* @brief Constructor
* @param DOMAIN_ID - the domain ID
* @param uint32_t - the projected size of the domain
*/
- PrdfRuleChipDomain( DOMAIN_ID i_did, uint32_t i_size ) :
- DomainContainer<PrdfRuleChip>( i_did, i_size )
+ RuleChipDomain( DOMAIN_ID i_did, uint32_t i_size ) :
+ DomainContainer<RuleChip>( i_did, i_size )
{}
/** @fn Query
@@ -74,4 +77,6 @@ class PrdfRuleChipDomain : public DomainContainer<PrdfRuleChip>
virtual void Order( ATTENTION_TYPE i_attnType);
};
+} // end namespace PRDF
+
#endif /* PRDFRULECHIPDOMAIN_H */
diff --git a/src/usr/diag/prdf/common/framework/config/prdfSystemSpecific.H b/src/usr/diag/prdf/common/framework/config/prdfSystemSpecific.H
index 295c67486..af173c3aa 100755
--- a/src/usr/diag/prdf/common/framework/config/prdfSystemSpecific.H
+++ b/src/usr/diag/prdf/common/framework/config/prdfSystemSpecific.H
@@ -45,10 +45,15 @@
#include <iipConfigurator.h>
#include <iipstep.h>
-namespace PrdfSystemSpecific
+namespace PRDF
+{
+
+namespace SystemSpecific
{
PRDF::Configurator * getConfiguratorPtr();
void postAnalysisWorkarounds(STEP_CODE_DATA_STRUCT & i_sdc);
};
+} // end namespace PRDF
+
#endif
diff --git a/src/usr/diag/prdf/common/framework/config/xspprdAccessPllChip.C b/src/usr/diag/prdf/common/framework/config/xspprdAccessPllChip.C
index b1f2b91e9..609f76595 100755
--- a/src/usr/diag/prdf/common/framework/config/xspprdAccessPllChip.C
+++ b/src/usr/diag/prdf/common/framework/config/xspprdAccessPllChip.C
@@ -49,6 +49,9 @@
// User Types
//----------------------------------------------------------------------
+namespace PRDF
+{
+
//----------------------------------------------------------------------
// Constants
//----------------------------------------------------------------------
@@ -192,15 +195,5 @@ void AccessPllChip::CapturePll(STEP_CODE_DATA_STRUCT & serviceData)
(serviceData.service_data->GetCaptureData()).Add(GetChipHandle(), PLL_ID ,pll_lock_reg);
}
-// --------------------------------------------------------------------
-// --------------------------------------------------------------------
+} // end namespace PRDF
-
-// Change Log *********************************************************
-//
-// Flag Reason Vers Date Coder Description
-// ---- --------- ---- -------- -------- ------------------------------
-// v5r2 04/14/00 mkobler Initial Creation
-// 512857 fips240 07/29/05 dgilbert add AccessPllChip
-//
-// End Change Log *****************************************************
diff --git a/src/usr/diag/prdf/common/framework/config/xspprdAccessPllChip.h b/src/usr/diag/prdf/common/framework/config/xspprdAccessPllChip.h
index 7abc4d237..bc6a78792 100755
--- a/src/usr/diag/prdf/common/framework/config/xspprdAccessPllChip.h
+++ b/src/usr/diag/prdf/common/framework/config/xspprdAccessPllChip.h
@@ -40,6 +40,9 @@
#include <iipchip.h>
+namespace PRDF
+{
+
//--------------------------------------------------------------------
// Forward References
//--------------------------------------------------------------------
@@ -141,4 +144,6 @@ inline AccessPllChip::AccessPllChip( TARGETING::TargetHandle_t i_target ) :
CHIP_CLASS(i_target)
{}
+} // end namespace PRDF
+
#endif /* xspprdAccessPllChip_h */
OpenPOWER on IntegriCloud
diff --git a/src/usr/diag/prdf/common/framework/config/iipSystem.C b/src/usr/diag/prdf/common/framework/config/iipSystem.C
index 4fda713cf..b66f2f0de 100755
--- a/src/usr/diag/prdf/common/framework/config/iipSystem.C
+++ b/src/usr/diag/prdf/common/framework/config/iipSystem.C
@@ -54,6 +54,9 @@
#include <prdfMfgThresholdMgr.H>
#endif
+namespace PRDF
+{
+
//----------------------------------------------------------------------
// User Types
//----------------------------------------------------------------------
@@ -102,9 +105,9 @@ System::~System(void)
ResolutionFactory::Access().Reset();
#ifndef __HOSTBOOT_MODULE
// FIXME: need to implement PrdfMfgThresholdMgr in Hostboot
// clear the MfgThresholdMgr
- PrdfMfgThresholdMgr::getInstance()->reset();
+ MfgThresholdMgr::getInstance()->reset();
#endif
// clear the threshold policies
@@ -148,8 +151,6 @@ Domain * System::GetDomain(DOMAIN_ID domainId)
void System::AddChips(ChipContainerIterator begin,
ChipContainerIterator end)
{
- using namespace PRDF;
-
size_t l_size = 0;
if(begin < end) l_size = end-begin;
else l_size = begin-end;
@@ -189,8 +190,6 @@ void System::RemoveStoppedChips(TARGETING::TargetHandle_t i_pchipHandle)
void System::RemoveNonFunctionalChips()
{
- using namespace PRDF;
-
ChipMapType l_chips;
for(ChipMapType::iterator chipIterator = chips.begin();
@@ -255,8 +254,6 @@ void System::Initialize(void)
int System::Analyze(STEP_CODE_DATA_STRUCT & serviceData,
ATTENTION_TYPE attentionType)
{
- using namespace PRDF;
-
SYSTEM_DEBUG_CLASS sysdebug;
Domain * domainAtAttentionPtr = NULL;
ServiceDataCollector * l_saved_sdc = NULL;
@@ -336,3 +333,6 @@ int System::Analyze(STEP_CODE_DATA_STRUCT & serviceData,
return(rc);
}
+
+} // end namespace PRDF
+
@@ -102,9 +105,9 @@ System::~System(void)
ResolutionFactory::Access().Reset();
#ifndef __HOSTBOOT_MODULE
- // FIXME: need to implement PrdfMfgThresholdMgr in Hostboot
+ // FIXME: need to implement MfgThresholdMgr in Hostboot
// clear the MfgThresholdMgr